# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
#
# Generation mode: Incremental
# --------------------------------------------------------------------------
from knack.help_files import helps  # pylint: disable=unused-import

from .generated._help import helps  # pylint: disable=reimported
try:
    from .manual._help import helps  # pylint: disable=reimported
except ImportError:
    pass

# pylint: disable=line-too-long, too-many-lines

helps['billing'] = """
type: group
short-summary: Manage Azure Billing.
"""

helps['billing enrollment-account'] = """
type: group
short-summary: Get enrollment accounts.
"""

helps['billing invoice'] = """
type: group
short-summary: Get billing invoices for a subscription.
"""

helps['billing period'] = """
type: group
short-summary: Get billing periods for a subscription.
"""
